@@ -1,29 +1,29 @@
 # -*- coding: utf-8 -*-
 """Django page CMS ``managers``."""
-import itertools, re
-from datetime import datetime
-
-from django.db import models, connection
-from django.contrib.sites.models import Site
-from django.db.models import Q
-from django.core.cache import cache
-from django.contrib.auth.models import User
-
 from pages import settings
 from pages.utils import normalize_url, filter_link
 from pages.http import get_slug_and_relative_path
 
+from django.db import models, connection
+from django.db.models import Q
+from django.core.cache import cache
+from django.contrib.auth.models import User
+
+from datetime import datetime
+
+
 class PageManager(models.Manager):
     """
     Page manager provide several filters to obtain pages :class:`QuerySet`
-    that respect the page settings.
+    that respect the page attributes and project settings.
     """
 
     def populate_pages(self, parent=None, child=5, depth=5):
-        """Create a population of pages for testing purpose."""
+        """Create a population of :class:`Page <pages.models.Page>`
+        for testing purpose."""
         from pages.models import Content
         author = User.objects.all()[0]
-        if depth==0:
+        if depth == 0:
             return
         p = self.model(parent=parent, author=author,
             status=self.model.PUBLISHED)
@@ -32,7 +32,7 @@ class PageManager(models.Manager):
             language='en-us', page=p).save()
         Content(body='page-'+str(p.id), type='slug',
             language='en-us', page=p).save()
-        for child in range(1, child):
+        for child in range(1, child+1):
             self.populate_pages(parent=p, child=child, depth=(depth-1))
     
     def on_site(self, site_id=None):
@@ -80,7 +80,8 @@ class PageManager(models.Manager):
         return queryset
 
     def published(self):
-        """Creates a :class:`QuerySet` of published filter."""
+        """Creates a :class:`QuerySet` of published
+        :class:`Page <pages.models.Page>`."""
         return self.filter_published(self)
 
     def drafts(self):
@@ -116,9 +117,12 @@ class PageManager(models.Manager):
                     return page
         return None
 
+
 class ContentManager(models.Manager):
     """:class:`Content <pages.models.Content>` manager methods"""
 
+    PAGE_CONTENT_DICT_KEY = "page_content_dict_%d_%s_%d"
+
     def sanitize(self, content):
         """Sanitize a string in order to avoid possible XSS using
         ``html5lib``."""
@@ -182,12 +186,12 @@ class ContentManager(models.Manager):
         :param ctype: the content type.
         :param language_fallback: fallback to another language if ``True``.
         """
-        PAGE_CONTENT_DICT_KEY = "page_content_dict_%d_%s_%d"
         if not language:
             language = settings.PAGE_DEFAULT_LANGUAGE
 
         frozen = int(bool(page.freeze_date))
-        content_dict = cache.get(PAGE_CONTENT_DICT_KEY % (page.id, ctype, frozen))
+        content_dict = cache.get(self.PAGE_CONTENT_DICT_KEY %
+            (page.id, ctype, frozen))
 
         # fill a dict object for each language
         if not content_dict:
@@ -200,13 +204,14 @@ class ContentManager(models.Manager):
                 }
                 if page.freeze_date:
                     params['creation_date__lte'] = page.freeze_date
-                language=lang[0]
+                # using the same variable name "language" introduce nasty bugs.
+                lang = lang[0]
                 try:
                     content = self.filter(**params).latest()
-                    content_dict[language] = content.body
+                    content_dict[lang] = content.body
                 except self.model.DoesNotExist:
-                    content_dict[language] = ''
-            cache.set(PAGE_CONTENT_DICT_KEY % (page.id, ctype, frozen),
+                    content_dict[lang] = ''
+            cache.set(self.PAGE_CONTENT_DICT_KEY % (page.id, ctype, frozen),
                 content_dict)
 
         if language in content_dict and content_dict[language]:
@@ -250,29 +255,6 @@ class ContentManager(models.Manager):
         cursor.execute(sql, ('slug', slug, ))
         return [c[0] for c in cursor.fetchall()]
 
-class PagePermissionManager(models.Manager):
-    """Hierachic page permission manager."""
-
-    def get_page_id_list(self, user):
-        """Give a list of :class:`Page <pages.models.Page>` ids where the
-        user has rights or the string
-        "All" if the user has all rights.
-
-        :param user: the interested user.
-        """
-        if user.is_superuser:
-            return 'All'
-        id_list = []
-        for perm in self.filter(user=user):
-            if perm.type == 0:
-                return "All"
-            if perm.page.id not in id_list:
-                id_list.append(perm.page.id)
-            if perm.type == 2:
-                for page in perm.page.get_descendants():
-                    if page.id not in id_list:
-                        id_list.append(page.id)
-        return id_list
 
 class PageAliasManager(models.Manager):
     """:class:`PageAlias <pages.models.PageAlias>` manager."""
