@@ -1,4 +1,5 @@
-__all__ = ('register_urlconf',)
+"""Django page CMS urlconf registry."""
+
 from django.utils.translation import ugettext as _
 
 class UrlconfAlreadyRegistered(Exception):
@@ -6,13 +7,11 @@ class UrlconfAlreadyRegistered(Exception):
     An attempt was made to register a widget for Django page CMS more
     than once.
     """
-    pass
 
 class UrlconfNotFound(Exception):
     """
     The requested widget was not found
     """
-    pass
 
 registry = []
 
@@ -29,7 +28,7 @@ def get_choices():
 def register_urlconf(name, urlconf, label=None):
     for urlconf_tuple in registry:
         if urlconf_tuple[0] == name:
-            raise urlconfAlreadyRegistered(
+            raise UrlconfAlreadyRegistered(
                 _('The urlconf %s has already been registered.') % name)
     urlconf_tuple = (name, urlconf, label, urlconf)
     registry.append(urlconf_tuple)
@@ -38,5 +37,5 @@ def get_urlconf(name):
     for urlconf_tuple in registry:
         if urlconf_tuple[0] == name:
             return urlconf_tuple[1]
-    raise urlconfNotFound(
+    raise UrlconfNotFound(
         _('The urlconf %s has not been registered.') % name)
\ No newline at end of file
